##
##  dar.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2021 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         dar
Summary:      Disk Archiver
URL:          http://dar.linux.free.fr/
Vendor:       Denis Corbin et al.
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Archiver
License:      GPL
Version:      2.6.14
Release:      20210314

#   list of sources
Source0:      http://downloads.sourceforge.net/dar/dar-%{version}.tar.gz
Patch0:       dar.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, gcc::with_cxx = yes
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  getopt, bzip2, zlib, gcrypt, gpg-error, lzo
PreReq:       getopt, bzip2, zlib, gcrypt, gpg-error, lzo

%description
    dar(1) is a shell command that backups directory trees and files.
    It provides filters, differential backup, slices, directory tree
    snapshots, compression, direct file access, hard link consideration,
    extended attributes, archive testing, remote operations, isolation,
    scrambling, strong encryption, flat restore, data protection,
    archive merging, archive subsetting, etc.

%track
    prog dar = {
        version   = %{version}
        url       = http://sourceforge.net/projects/dar/files/
        regex     = dar-(\d+\.\d+\.\d+)\.tar\.gz
    }

%prep
    %setup -q
    %patch -p0

%build
    %{l_shtool} subst \
        -e 's;-lgnugetopt;-lgetopt;g' \
        -e 's;<getopt.h>;"getopt.h";g' \
        configure
    ( echo "ac_cv_lib_gnugetopt_getopt_long=yes"
    ) >config.cache
    CC="%{l_cc}" \
    CXX="%{l_cxx}" \
    CFLAGS="%{l_cflags -O}" \
    CXXFLAGS="%{l_cxxflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    LIBS="-lgetopt" \
    ./configure \
        --cache-file=./config.cache \
        --prefix=%{l_prefix} \
        --sysconfdir=%{l_prefix}/etc/dar \
        --mandir=%{l_prefix}/man \
        --disable-thread-safe \
        --disable-dar-static \
        --disable-upx \
        --disable-shared \
        --disable-nls
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/dar >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/dar/*'

%files -f files

%clean

